import { Message, GuildTextableChannel } from 'eris';
import moment, { unitOfTime } from 'moment';
import { Client, Command } from '../class';

export default class Slowmode extends Command {
  constructor(client: Client) {
    super(client);
    this.name = 'slowmode';
    this.description = 'Set slowmode to a channel.';
    this.usage = 'slowmode <length[unit]>';
    this.permissions = 1;
    this.guildOnly = true;
    this.enabled = true;
  }

  public async run(message: Message<GuildTextableChannel>, args: string[]) {
    try {
      if (!args[0]) return this.error(message.channel, 'This command requires an argument.');

      const Length = args[0].match(/[a-z]+|[^a-z]+/gi);
      const length = Number(Length[0]);
      if (Number.isNaN(length)) return this.error(message.channel, 'Could not determine the slowmode time.');
      const unit = Length[1] as unitOfTime.Base;
      const momentSeconds: number = moment.duration(length, unit || 's').asSeconds();

      if (momentSeconds > 21600 || momentSeconds < 0) return this.error(message.channel, 'Slowmode must be between 0 seconds and 6 hours.');

      return message.channel.edit({ rateLimitPerUser: momentSeconds }).then((c) => message.addReaction(':success:477618704155410452'));
    } catch (err) {
      return this.client.util.handleError(err, message, this);
    }
  }
}
